==> mutils-wechat-miniprogram-0.2.5-sources.jar: org/mutils/wechat/miniprogram/model/UserInfoModel.java <==
package org.mutils.wechat.miniprogram.model;

import cn.minsin.core.rule.ModelRule;

public class UserInfoModel extends ModelRule {

	/**
	 * 
	 */
	private static final long serialVersionUID = 4390557940217451678L;
	
	private String openId;
	private String nickName;
	private String gender;
	private String language;
	private String city;
	private String province;
	private String country;
	private String avatarUrl;
	private String unionId;
	private Object watermark;
	public String getOpenId() {
		return openId;
	}
	public void setOpenId(String openId) {
		this.openId = openId;
	}
	public String getNickName() {
		return nickName;
	}
	public void setNickName(String nickName) {
		this.nickName = nickName;
	}
	public String getGender() {
		return gender;
	}
	public void setGender(String gender) {
		this.gender = gender;
	}
	public String getLanguage() {
		return language;
	}
	public void setLanguage(String language) {
		this.language = language;
	}
	public String getCity() {
		return city;
	}
	public void setCity(String city) {
		this.city = city;
	}
	public String getProvince() {
		return province;
	}
	public void setProvince(String province) {
		this.province = province;
	}
	public String getCountry() {
		return country;
	}
	public void setCountry(String country) {
		this.country = country;
	}
	public String getAvatarUrl() {
		return avatarUrl;
	}
	public void setAvatarUrl(String avatarUrl) {
		this.avatarUrl = avatarUrl;
	}
	public String getUnionId() {
		return unionId;
	}
	public void setUnionId(String unionId) {
		this.unionId = unionId;
	}
	public Object getWatermark() {
		return watermark;
	}
	public void setWatermark(Object watermark) {
		this.watermark = watermark;
	}
	
}

==> mutils-wechat-miniprogram-0.3.3-sources.jar: org/mutils/wechat/miniprogram/model/UserInfoModel.java <==
package org.mutils.wechat.miniprogram.model;

import cn.minsin.core.rule.AbstractModelRule;

public class UserInfoModel extends AbstractModelRule {

	/**
	 * 
	 */
	private static final long serialVersionUID = 4390557940217451678L;
	
	private String openId;
	private String nickName;
	private String gender;
	private String language;
	private String city;
	private String province;
	private String country;
	private String avatarUrl;
	private String unionId;
	private Object watermark;
	public String getOpenId() {
		return openId;
	}
	public void setOpenId(String openId) {
		this.openId = openId;
	}
	public String getNickName() {
		return nickName;
	}
	public void setNickName(String nickName) {
		this.nickName = nickName;
	}
	public String getGender() {
		return gender;
	}
	public void setGender(String gender) {
		this.gender = gender;
	}
	public String getLanguage() {
		return language;
	}
	public void setLanguage(String language) {
		this.language = language;
	}
	public String getCity() {
		return city;
	}
	public void setCity(String city) {
		this.city = city;
	}
	public String getProvince() {
		return province;
	}
	public void setProvince(String province) {
		this.province = province;
	}
	public String getCountry() {
		return country;
	}
	public void setCountry(String country) {
		this.country = country;
	}
	public String getAvatarUrl() {
		return avatarUrl;
	}
	public void setAvatarUrl(String avatarUrl) {
		this.avatarUrl = avatarUrl;
	}
	public String getUnionId() {
		return unionId;
	}
	public void setUnionId(String unionId) {
		this.unionId = unionId;
	}
	public Object getWatermark() {
		return watermark;
	}
	public void setWatermark(Object watermark) {
		this.watermark = watermark;
	}
	
}
